@@ -11,8 +11,8 @@ from office.api.testApi import ruiming
 
 print('=' * 30)
 print('【python-office库】，功能持续更新中')
-print('全部功能 - 说明书 -：https://www.python-office.com/')
 print('使用有问题 or 提交你的功能需求 or 参与项目开发')
-print('请+【开发者微信】：http://t.cn/A6SSrID0')
-print('本开源项目的源码：https://github.com/CoderWanFeng/python-office')
+print('1、全部功能说明书：https://www.python-office.com/')
+print('2、请+【项目交流群】：http://t.cn/A6SSrID0')
+print('3、本开源项目的源码仓库：https://github.com/CoderWanFeng/python-office')
 print('=' * 30)
