@@ -2,6 +2,7 @@ import os
 from alive_progress import alive_bar
 
 import pathlib
+import openpyxl
 
 from office.lib.utils.time_utils import time_count_dec
 
@@ -35,9 +36,9 @@ class MainFile():
     def file_name_insert_content(self, file_path, insert_position: int, insert_content: str):
         """
 
-        :param Path: 文件存放路径
-        :param InsertPosition: 插入位置（内容将插入在此之后，如果输入位置大于文件主名长度将插入在末尾）
-        :param InsertContent: 插入内容
+        :param file_path: 文件存放路径
+        :param insert_position: 插入位置（内容将插入在此之后，如果输入位置大于文件主名长度将插入在末尾）
+        :param insert_content: 插入内容
         """
         Path = pathlib.Path(file_path).resolve()
         if Path.is_dir():
@@ -62,8 +63,8 @@ class MainFile():
     def file_name_add_prefix(self, file_path, prefix_content: str):
         """
 
-        :param Path: 文件存放路径
-        :param PrefixContent: 前缀内容
+        :param file_path: 文件存放路径
+        :param prefix_content: 前缀内容
         """
         Path = pathlib.Path(file_path).resolve()
         if Path.is_dir():
@@ -82,8 +83,8 @@ class MainFile():
     def file_name_add_postfix(self, file_path, postfix_content: str):
         """
 
-        :param Path: 文件存放路径
-        :param PostfixContent: 后缀内容
+        :param file_path: 文件存放路径
+        :param postfix_content: 后缀内容
         """
         Path = pathlib.Path(file_path).resolve()
         if Path.is_dir():
@@ -120,3 +121,20 @@ class MainFile():
             print(f"查找完成，共找到{i}个文件")
         else:
             print("请输入文件夹路径")
+
+    def output_file_list_to_excel(self,dir_path: str):
+        """
+        :param dir_path: 需要生成文件列表的目录
+        """
+        dir_path = pathlib.Path(dir_path).resolve()
+        if dir_path.is_dir():
+            dir_path_list = list(dir_path.glob("**/*"))
+            output_excel = openpyxl.Workbook()
+            output_excel_sheet = output_excel.active
+            output_excel_sheet.append(["完整路径", "文件所在路径", "文件名"])
+            for file_path in dir_path_list:
+                if file_path.is_file():
+                    output_excel_sheet.append([str(file_path), str(file_path.parent), str(file_path.name)])
+            output_excel.save(dir_path.joinpath("本目录文件列表.xlsx"))
+        else:
+            print("请输入正确的文件路径！")
\ No newline at end of file
