@@ -1,6 +1,6 @@
 import unittest
 
-from office.api.pdf import pdf2imgs, pdf2docx, add_img_water
+from office.api.pdf import *
 
 
 class TestExcel(unittest.TestCase):
@@ -17,3 +17,9 @@ class TestExcel(unittest.TestCase):
 
     def test_add_img_water(self):
         add_img_water(pdf_file_in='./pdf/add_img.pdf', pdf_file_mark='./pdf/in.pdf', pdf_file_out='add_img.pdf')
+
+    def test_add_watermark_by_parameters(self):
+        add_watermark_by_parameters(
+            pdf_file=r'C:\Users\Lenovo\Documents\WeChat Files\wxid_z91t05fqtrry22\FileStorage\MsgAttach\7ae419aa6a5f7c2fc32c594a69e28c6d\File\2022-06\2022眼科行业研究报告-动脉网-2022-52页.pdf',
+            mark_str='abc',
+            output_file_name='测试.pdf')
